@@ -6,7 +6,7 @@ use Cwd;
 use base qw(Module::Install::Base);
 use vars qw($VERSION);
 
-$VERSION = '0.10';
+$VERSION = '0.12';
 
 sub githubmeta {
   my $self = shift;
@@ -19,7 +19,13 @@ sub githubmeta {
   $git_url =~ s![\w\-]+\@([^:]+):!git://$1/!;
   $http_url =~ s![\w\-]+\@([^:]+):!http://$1/!;
   $http_url =~ s!\.git$!/tree!;
-  $self->repository( $git_url );
+  $self->repository(
+      {
+          type => 'git',
+          url  => $git_url,
+          web  => $http_url,
+      },
+  );
   $self->homepage( $http_url ) unless $self->homepage();
   return 1;
 }
